# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: oracle/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from oracle.v1 import oracle_pb2 as oracle_dot_v1_dot_oracle__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='oracle/v1/query.proto',
  package='oracle.v1',
  syntax='proto3',
  serialized_options=b'Z,github.com/bandprotocol/chain/x/oracle/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15oracle/v1/query.proto\x12\toracle.v1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x16oracle/v1/oracle.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x14\n\x12QueryCountsRequest\"d\n\x13QueryCountsResponse\x12\x19\n\x11\x64\x61ta_source_count\x18\x01 \x01(\x03\x12\x1b\n\x13oracle_script_count\x18\x02 \x01(\x03\x12\x15\n\rrequest_count\x18\x03 \x01(\x03\"%\n\x10QueryDataRequest\x12\x11\n\tdata_hash\x18\x01 \x01(\t\"!\n\x11QueryDataResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"0\n\x16QueryDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\x03\"E\n\x17QueryDataSourceResponse\x12*\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32\x15.oracle.v1.DataSource\"4\n\x18QueryOracleScriptRequest\x12\x18\n\x10oracle_script_id\x18\x01 \x01(\x03\"K\n\x19QueryOracleScriptResponse\x12.\n\roracle_script\x18\x01 \x01(\x0b\x32\x17.oracle.v1.OracleScript\")\n\x13QueryRequestRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\x03\"\x88\x01\n\x14QueryRequestResponse\x12#\n\x07request\x18\x01 \x01(\x0b\x32\x12.oracle.v1.Request\x12(\n\x07reports\x18\x02 \x03(\x0b\x32\x11.oracle.v1.ReportB\x04\xc8\xde\x1f\x00\x12!\n\x06result\x18\x03 \x01(\x0b\x32\x11.oracle.v1.Result\"8\n\x1bQueryPendingRequestsRequest\x12\x19\n\x11validator_address\x18\x01 \x01(\t\"C\n\x1cQueryPendingRequestsResponse\x12#\n\x0brequest_ids\x18\x01 \x03(\x03\x42\x0e\xe2\xde\x1f\nRequestIDs\"\x14\n\x12QueryParamsRequest\">\n\x13QueryParamsResponse\x12\'\n\x06params\x18\x01 \x01(\x0b\x32\x11.oracle.v1.ParamsB\x04\xc8\xde\x1f\x00\"2\n\x15QueryValidatorRequest\x12\x19\n\x11validator_address\x18\x01 \x01(\t\"D\n\x16QueryValidatorResponse\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x1a.oracle.v1.ValidatorStatus\"2\n\x15QueryReportersRequest\x12\x19\n\x11validator_address\x18\x01 \x01(\t\"*\n\x16QueryReportersResponse\x12\x10\n\x08reporter\x18\x01 \x03(\t\"\x1e\n\x1cQueryActiveValidatorsRequest\"O\n\x1dQueryActiveValidatorsResponse\x12.\n\nvalidators\x18\x01 \x03(\x0b\x32\x1a.oracle.v1.ActiveValidator\"m\n\x19QueryRequestSearchRequest\x12\x18\n\x10oracle_script_id\x18\x01 \x01(\x03\x12\x10\n\x08\x63\x61lldata\x18\x02 \x01(\t\x12\x11\n\task_count\x18\x03 \x01(\x04\x12\x11\n\tmin_count\x18\x04 \x01(\x04\"N\n\x1aQueryRequestSearchResponse\x12\x30\n\x07request\x18\x01 \x01(\x0b\x32\x1f.oracle.v1.QueryRequestResponse\"Q\n\x18QueryRequestPriceRequest\x12\x0f\n\x07symbols\x18\x01 \x03(\t\x12\x11\n\task_count\x18\x02 \x01(\x03\x12\x11\n\tmin_count\x18\x03 \x01(\x03\"J\n\x19QueryRequestPriceResponse\x12-\n\rprice_results\x18\x01 \x03(\x0b\x32\x16.oracle.v1.PriceResult\"\x94\x01\n\x1fQueryRequestVerificationRequest\x12\x10\n\x08\x63hain_id\x18\x01 \x01(\t\x12\x11\n\tvalidator\x18\x02 \x01(\t\x12\x12\n\nrequest_id\x18\x03 \x01(\x03\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\x03\x12\x10\n\x08reporter\x18\x05 \x01(\t\x12\x11\n\tsignature\x18\x06 \x01(\x0c\"\x88\x01\n QueryRequestVerificationResponse\x12\x10\n\x08\x63hain_id\x18\x01 \x01(\t\x12\x11\n\tvalidator\x18\x02 \x01(\t\x12\x12\n\nrequest_id\x18\x03 \x01(\x03\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\x03\x12\x16\n\x0e\x64\x61ta_source_id\x18\x05 \x01(\x03\"S\n\x17QueryRequestPoolRequest\x12\x13\n\x0brequest_key\x18\x01 \x01(\t\x12\x0f\n\x07port_id\x18\x02 \x01(\t\x12\x12\n\nchannel_id\x18\x03 \x01(\t\"\x96\x01\n\x18QueryRequestPoolResponse\x12\x1c\n\x14request_pool_address\x18\x01 \x01(\t\x12\\\n\x07\x62\x61lance\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins2\xb0\x0e\n\x05Query\x12\x62\n\x06\x43ounts\x12\x1d.oracle.v1.QueryCountsRequest\x1a\x1e.oracle.v1.QueryCountsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/oracle/v1/counts\x12\x66\n\x04\x44\x61ta\x12\x1b.oracle.v1.QueryDataRequest\x1a\x1c.oracle.v1.QueryDataResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/oracle/v1/data/{data_hash}\x12\x85\x01\n\nDataSource\x12!.oracle.v1.QueryDataSourceRequest\x1a\".oracle.v1.QueryDataSourceResponse\"0\x82\xd3\xe4\x93\x02*\x12(/oracle/v1/data_sources/{data_source_id}\x12\x8f\x01\n\x0cOracleScript\x12#.oracle.v1.QueryOracleScriptRequest\x1a$.oracle.v1.QueryOracleScriptResponse\"4\x82\xd3\xe4\x93\x02.\x12,/oracle/v1/oracle_scripts/{oracle_script_id}\x12t\n\x07Request\x12\x1e.oracle.v1.QueryRequestRequest\x1a\x1f.oracle.v1.QueryRequestResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /oracle/v1/requests/{request_id}\x12\x9b\x01\n\x0fPendingRequests\x12&.oracle.v1.QueryPendingRequestsRequest\x1a\'.oracle.v1.QueryPendingRequestsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//oracle/v1/pending_requests/{validator_address}\x12\x83\x01\n\tValidator\x12 .oracle.v1.QueryValidatorRequest\x1a!.oracle.v1.QueryValidatorResponse\"1\x82\xd3\xe4\x93\x02+\x12)/oracle/v1/validators/{validator_address}\x12\x82\x01\n\tReporters\x12 .oracle.v1.QueryReportersRequest\x1a!.oracle.v1.QueryReportersResponse\"0\x82\xd3\xe4\x93\x02*\x12(/oracle/v1/reporters/{validator_address}\x12\x8b\x01\n\x10\x41\x63tiveValidators\x12\'.oracle.v1.QueryActiveValidatorsRequest\x1a(.oracle.v1.QueryActiveValidatorsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/oracle/v1/active_validators\x12\x62\n\x06Params\x12\x1d.oracle.v1.QueryParamsRequest\x1a\x1e.oracle.v1.QueryParamsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/oracle/v1/params\x12\x7f\n\rRequestSearch\x12$.oracle.v1.QueryRequestSearchRequest\x1a%.oracle.v1.QueryRequestSearchResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/oracle/v1/request_search\x12|\n\x0cRequestPrice\x12#.oracle.v1.QueryRequestPriceRequest\x1a$.oracle.v1.QueryRequestPriceResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/oracle/v1/request_prices\x12\x91\x01\n\x13RequestVerification\x12*.oracle.v1.QueryRequestVerificationRequest\x1a+.oracle.v1.QueryRequestVerificationResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/oracle/v1/verify_request\x12\x9c\x01\n\x0bRequestPool\x12\".oracle.v1.QueryRequestPoolRequest\x1a#.oracle.v1.QueryRequestPoolResponse\"D\x82\xd3\xe4\x93\x02>\x12</oracle/v1/request_pool/{request_key}/{port_id}/{channel_id}B.Z,github.com/bandprotocol/chain/x/oracle/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,oracle_dot_v1_dot_oracle__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])




_QUERYCOUNTSREQUEST = _descriptor.Descriptor(
  name='QueryCountsRequest',
  full_name='oracle.v1.QueryCountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=164,
)


_QUERYCOUNTSRESPONSE = _descriptor.Descriptor(
  name='QueryCountsResponse',
  full_name='oracle.v1.QueryCountsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_source_count', full_name='oracle.v1.QueryCountsResponse.data_source_count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_script_count', full_name='oracle.v1.QueryCountsResponse.oracle_script_count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_count', full_name='oracle.v1.QueryCountsResponse.request_count', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=266,
)


_QUERYDATAREQUEST = _descriptor.Descriptor(
  name='QueryDataRequest',
  full_name='oracle.v1.QueryDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_hash', full_name='oracle.v1.QueryDataRequest.data_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=268,
  serialized_end=305,
)


_QUERYDATARESPONSE = _descriptor.Descriptor(
  name='QueryDataResponse',
  full_name='oracle.v1.QueryDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='oracle.v1.QueryDataResponse.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=307,
  serialized_end=340,
)


_QUERYDATASOURCEREQUEST = _descriptor.Descriptor(
  name='QueryDataSourceRequest',
  full_name='oracle.v1.QueryDataSourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_source_id', full_name='oracle.v1.QueryDataSourceRequest.data_source_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=390,
)


_QUERYDATASOURCERESPONSE = _descriptor.Descriptor(
  name='QueryDataSourceResponse',
  full_name='oracle.v1.QueryDataSourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_source', full_name='oracle.v1.QueryDataSourceResponse.data_source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=392,
  serialized_end=461,
)


_QUERYORACLESCRIPTREQUEST = _descriptor.Descriptor(
  name='QueryOracleScriptRequest',
  full_name='oracle.v1.QueryOracleScriptRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle_script_id', full_name='oracle.v1.QueryOracleScriptRequest.oracle_script_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=515,
)


_QUERYORACLESCRIPTRESPONSE = _descriptor.Descriptor(
  name='QueryOracleScriptResponse',
  full_name='oracle.v1.QueryOracleScriptResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle_script', full_name='oracle.v1.QueryOracleScriptResponse.oracle_script', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=517,
  serialized_end=592,
)


_QUERYREQUESTREQUEST = _descriptor.Descriptor(
  name='QueryRequestRequest',
  full_name='oracle.v1.QueryRequestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.QueryRequestRequest.request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=594,
  serialized_end=635,
)


_QUERYREQUESTRESPONSE = _descriptor.Descriptor(
  name='QueryRequestResponse',
  full_name='oracle.v1.QueryRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='oracle.v1.QueryRequestResponse.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reports', full_name='oracle.v1.QueryRequestResponse.reports', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='oracle.v1.QueryRequestResponse.result', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=638,
  serialized_end=774,
)


_QUERYPENDINGREQUESTSREQUEST = _descriptor.Descriptor(
  name='QueryPendingRequestsRequest',
  full_name='oracle.v1.QueryPendingRequestsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_address', full_name='oracle.v1.QueryPendingRequestsRequest.validator_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=776,
  serialized_end=832,
)


_QUERYPENDINGREQUESTSRESPONSE = _descriptor.Descriptor(
  name='QueryPendingRequestsResponse',
  full_name='oracle.v1.QueryPendingRequestsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_ids', full_name='oracle.v1.QueryPendingRequestsResponse.request_ids', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\nRequestIDs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=834,
  serialized_end=901,
)


_QUERYPARAMSREQUEST = _descriptor.Descriptor(
  name='QueryParamsRequest',
  full_name='oracle.v1.QueryParamsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=903,
  serialized_end=923,
)


_QUERYPARAMSRESPONSE = _descriptor.Descriptor(
  name='QueryParamsResponse',
  full_name='oracle.v1.QueryParamsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='oracle.v1.QueryParamsResponse.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=925,
  serialized_end=987,
)


_QUERYVALIDATORREQUEST = _descriptor.Descriptor(
  name='QueryValidatorRequest',
  full_name='oracle.v1.QueryValidatorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_address', full_name='oracle.v1.QueryValidatorRequest.validator_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=989,
  serialized_end=1039,
)


_QUERYVALIDATORRESPONSE = _descriptor.Descriptor(
  name='QueryValidatorResponse',
  full_name='oracle.v1.QueryValidatorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='oracle.v1.QueryValidatorResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1041,
  serialized_end=1109,
)


_QUERYREPORTERSREQUEST = _descriptor.Descriptor(
  name='QueryReportersRequest',
  full_name='oracle.v1.QueryReportersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_address', full_name='oracle.v1.QueryReportersRequest.validator_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1111,
  serialized_end=1161,
)


_QUERYREPORTERSRESPONSE = _descriptor.Descriptor(
  name='QueryReportersResponse',
  full_name='oracle.v1.QueryReportersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reporter', full_name='oracle.v1.QueryReportersResponse.reporter', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1163,
  serialized_end=1205,
)


_QUERYACTIVEVALIDATORSREQUEST = _descriptor.Descriptor(
  name='QueryActiveValidatorsRequest',
  full_name='oracle.v1.QueryActiveValidatorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1207,
  serialized_end=1237,
)


_QUERYACTIVEVALIDATORSRESPONSE = _descriptor.Descriptor(
  name='QueryActiveValidatorsResponse',
  full_name='oracle.v1.QueryActiveValidatorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validators', full_name='oracle.v1.QueryActiveValidatorsResponse.validators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1239,
  serialized_end=1318,
)


_QUERYREQUESTSEARCHREQUEST = _descriptor.Descriptor(
  name='QueryRequestSearchRequest',
  full_name='oracle.v1.QueryRequestSearchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle_script_id', full_name='oracle.v1.QueryRequestSearchRequest.oracle_script_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calldata', full_name='oracle.v1.QueryRequestSearchRequest.calldata', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ask_count', full_name='oracle.v1.QueryRequestSearchRequest.ask_count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_count', full_name='oracle.v1.QueryRequestSearchRequest.min_count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1320,
  serialized_end=1429,
)


_QUERYREQUESTSEARCHRESPONSE = _descriptor.Descriptor(
  name='QueryRequestSearchResponse',
  full_name='oracle.v1.QueryRequestSearchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='oracle.v1.QueryRequestSearchResponse.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1431,
  serialized_end=1509,
)


_QUERYREQUESTPRICEREQUEST = _descriptor.Descriptor(
  name='QueryRequestPriceRequest',
  full_name='oracle.v1.QueryRequestPriceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbols', full_name='oracle.v1.QueryRequestPriceRequest.symbols', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ask_count', full_name='oracle.v1.QueryRequestPriceRequest.ask_count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_count', full_name='oracle.v1.QueryRequestPriceRequest.min_count', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1511,
  serialized_end=1592,
)


_QUERYREQUESTPRICERESPONSE = _descriptor.Descriptor(
  name='QueryRequestPriceResponse',
  full_name='oracle.v1.QueryRequestPriceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price_results', full_name='oracle.v1.QueryRequestPriceResponse.price_results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1594,
  serialized_end=1668,
)


_QUERYREQUESTVERIFICATIONREQUEST = _descriptor.Descriptor(
  name='QueryRequestVerificationRequest',
  full_name='oracle.v1.QueryRequestVerificationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='oracle.v1.QueryRequestVerificationRequest.chain_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.QueryRequestVerificationRequest.validator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.QueryRequestVerificationRequest.request_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_id', full_name='oracle.v1.QueryRequestVerificationRequest.external_id', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reporter', full_name='oracle.v1.QueryRequestVerificationRequest.reporter', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='oracle.v1.QueryRequestVerificationRequest.signature', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1671,
  serialized_end=1819,
)


_QUERYREQUESTVERIFICATIONRESPONSE = _descriptor.Descriptor(
  name='QueryRequestVerificationResponse',
  full_name='oracle.v1.QueryRequestVerificationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='oracle.v1.QueryRequestVerificationResponse.chain_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.QueryRequestVerificationResponse.validator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.QueryRequestVerificationResponse.request_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_id', full_name='oracle.v1.QueryRequestVerificationResponse.external_id', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source_id', full_name='oracle.v1.QueryRequestVerificationResponse.data_source_id', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1822,
  serialized_end=1958,
)


_QUERYREQUESTPOOLREQUEST = _descriptor.Descriptor(
  name='QueryRequestPoolRequest',
  full_name='oracle.v1.QueryRequestPoolRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_key', full_name='oracle.v1.QueryRequestPoolRequest.request_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_id', full_name='oracle.v1.QueryRequestPoolRequest.port_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='oracle.v1.QueryRequestPoolRequest.channel_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1960,
  serialized_end=2043,
)


_QUERYREQUESTPOOLRESPONSE = _descriptor.Descriptor(
  name='QueryRequestPoolResponse',
  full_name='oracle.v1.QueryRequestPoolResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_pool_address', full_name='oracle.v1.QueryRequestPoolResponse.request_pool_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance', full_name='oracle.v1.QueryRequestPoolResponse.balance', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2046,
  serialized_end=2196,
)

_QUERYDATASOURCERESPONSE.fields_by_name['data_source'].message_type = oracle_dot_v1_dot_oracle__pb2._DATASOURCE
_QUERYORACLESCRIPTRESPONSE.fields_by_name['oracle_script'].message_type = oracle_dot_v1_dot_oracle__pb2._ORACLESCRIPT
_QUERYREQUESTRESPONSE.fields_by_name['request'].message_type = oracle_dot_v1_dot_oracle__pb2._REQUEST
_QUERYREQUESTRESPONSE.fields_by_name['reports'].message_type = oracle_dot_v1_dot_oracle__pb2._REPORT
_QUERYREQUESTRESPONSE.fields_by_name['result'].message_type = oracle_dot_v1_dot_oracle__pb2._RESULT
_QUERYPARAMSRESPONSE.fields_by_name['params'].message_type = oracle_dot_v1_dot_oracle__pb2._PARAMS
_QUERYVALIDATORRESPONSE.fields_by_name['status'].message_type = oracle_dot_v1_dot_oracle__pb2._VALIDATORSTATUS
_QUERYACTIVEVALIDATORSRESPONSE.fields_by_name['validators'].message_type = oracle_dot_v1_dot_oracle__pb2._ACTIVEVALIDATOR
_QUERYREQUESTSEARCHRESPONSE.fields_by_name['request'].message_type = _QUERYREQUESTRESPONSE
_QUERYREQUESTPRICERESPONSE.fields_by_name['price_results'].message_type = oracle_dot_v1_dot_oracle__pb2._PRICERESULT
_QUERYREQUESTPOOLRESPONSE.fields_by_name['balance'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
DESCRIPTOR.message_types_by_name['QueryCountsRequest'] = _QUERYCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['QueryCountsResponse'] = _QUERYCOUNTSRESPONSE
DESCRIPTOR.message_types_by_name['QueryDataRequest'] = _QUERYDATAREQUEST
DESCRIPTOR.message_types_by_name['QueryDataResponse'] = _QUERYDATARESPONSE
DESCRIPTOR.message_types_by_name['QueryDataSourceRequest'] = _QUERYDATASOURCEREQUEST
DESCRIPTOR.message_types_by_name['QueryDataSourceResponse'] = _QUERYDATASOURCERESPONSE
DESCRIPTOR.message_types_by_name['QueryOracleScriptRequest'] = _QUERYORACLESCRIPTREQUEST
DESCRIPTOR.message_types_by_name['QueryOracleScriptResponse'] = _QUERYORACLESCRIPTRESPONSE
DESCRIPTOR.message_types_by_name['QueryRequestRequest'] = _QUERYREQUESTREQUEST
DESCRIPTOR.message_types_by_name['QueryRequestResponse'] = _QUERYREQUESTRESPONSE
DESCRIPTOR.message_types_by_name['QueryPendingRequestsRequest'] = _QUERYPENDINGREQUESTSREQUEST
DESCRIPTOR.message_types_by_name['QueryPendingRequestsResponse'] = _QUERYPENDINGREQUESTSRESPONSE
DESCRIPTOR.message_types_by_name['QueryParamsRequest'] = _QUERYPARAMSREQUEST
DESCRIPTOR.message_types_by_name['QueryParamsResponse'] = _QUERYPARAMSRESPONSE
DESCRIPTOR.message_types_by_name['QueryValidatorRequest'] = _QUERYVALIDATORREQUEST
DESCRIPTOR.message_types_by_name['QueryValidatorResponse'] = _QUERYVALIDATORRESPONSE
DESCRIPTOR.message_types_by_name['QueryReportersRequest'] = _QUERYREPORTERSREQUEST
DESCRIPTOR.message_types_by_name['QueryReportersResponse'] = _QUERYREPORTERSRESPONSE
DESCRIPTOR.message_types_by_name['QueryActiveValidatorsRequest'] = _QUERYACTIVEVALIDATORSREQUEST
DESCRIPTOR.message_types_by_name['QueryActiveValidatorsResponse'] = _QUERYACTIVEVALIDATORSRESPONSE
DESCRIPTOR.message_types_by_name['QueryRequestSearchRequest'] = _QUERYREQUESTSEARCHREQUEST
DESCRIPTOR.message_types_by_name['QueryRequestSearchResponse'] = _QUERYREQUESTSEARCHRESPONSE
DESCRIPTOR.message_types_by_name['QueryRequestPriceRequest'] = _QUERYREQUESTPRICEREQUEST
DESCRIPTOR.message_types_by_name['QueryRequestPriceResponse'] = _QUERYREQUESTPRICERESPONSE
DESCRIPTOR.message_types_by_name['QueryRequestVerificationRequest'] = _QUERYREQUESTVERIFICATIONREQUEST
DESCRIPTOR.message_types_by_name['QueryRequestVerificationResponse'] = _QUERYREQUESTVERIFICATIONRESPONSE
DESCRIPTOR.message_types_by_name['QueryRequestPoolRequest'] = _QUERYREQUESTPOOLREQUEST
DESCRIPTOR.message_types_by_name['QueryRequestPoolResponse'] = _QUERYREQUESTPOOLRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryCountsRequest = _reflection.GeneratedProtocolMessageType('QueryCountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCOUNTSREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryCountsRequest)
  })
_sym_db.RegisterMessage(QueryCountsRequest)

QueryCountsResponse = _reflection.GeneratedProtocolMessageType('QueryCountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCOUNTSRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryCountsResponse)
  })
_sym_db.RegisterMessage(QueryCountsResponse)

QueryDataRequest = _reflection.GeneratedProtocolMessageType('QueryDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDATAREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryDataRequest)
  })
_sym_db.RegisterMessage(QueryDataRequest)

QueryDataResponse = _reflection.GeneratedProtocolMessageType('QueryDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDATARESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryDataResponse)
  })
_sym_db.RegisterMessage(QueryDataResponse)

QueryDataSourceRequest = _reflection.GeneratedProtocolMessageType('QueryDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDATASOURCEREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryDataSourceRequest)
  })
_sym_db.RegisterMessage(QueryDataSourceRequest)

QueryDataSourceResponse = _reflection.GeneratedProtocolMessageType('QueryDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDATASOURCERESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryDataSourceResponse)
  })
_sym_db.RegisterMessage(QueryDataSourceResponse)

QueryOracleScriptRequest = _reflection.GeneratedProtocolMessageType('QueryOracleScriptRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYORACLESCRIPTREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryOracleScriptRequest)
  })
_sym_db.RegisterMessage(QueryOracleScriptRequest)

QueryOracleScriptResponse = _reflection.GeneratedProtocolMessageType('QueryOracleScriptResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYORACLESCRIPTRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryOracleScriptResponse)
  })
_sym_db.RegisterMessage(QueryOracleScriptResponse)

QueryRequestRequest = _reflection.GeneratedProtocolMessageType('QueryRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestRequest)
  })
_sym_db.RegisterMessage(QueryRequestRequest)

QueryRequestResponse = _reflection.GeneratedProtocolMessageType('QueryRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestResponse)
  })
_sym_db.RegisterMessage(QueryRequestResponse)

QueryPendingRequestsRequest = _reflection.GeneratedProtocolMessageType('QueryPendingRequestsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPENDINGREQUESTSREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryPendingRequestsRequest)
  })
_sym_db.RegisterMessage(QueryPendingRequestsRequest)

QueryPendingRequestsResponse = _reflection.GeneratedProtocolMessageType('QueryPendingRequestsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPENDINGREQUESTSRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryPendingRequestsResponse)
  })
_sym_db.RegisterMessage(QueryPendingRequestsResponse)

QueryParamsRequest = _reflection.GeneratedProtocolMessageType('QueryParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryParamsRequest)
  })
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType('QueryParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryParamsResponse)
  })
_sym_db.RegisterMessage(QueryParamsResponse)

QueryValidatorRequest = _reflection.GeneratedProtocolMessageType('QueryValidatorRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryValidatorRequest)
  })
_sym_db.RegisterMessage(QueryValidatorRequest)

QueryValidatorResponse = _reflection.GeneratedProtocolMessageType('QueryValidatorResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryValidatorResponse)
  })
_sym_db.RegisterMessage(QueryValidatorResponse)

QueryReportersRequest = _reflection.GeneratedProtocolMessageType('QueryReportersRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREPORTERSREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryReportersRequest)
  })
_sym_db.RegisterMessage(QueryReportersRequest)

QueryReportersResponse = _reflection.GeneratedProtocolMessageType('QueryReportersResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREPORTERSRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryReportersResponse)
  })
_sym_db.RegisterMessage(QueryReportersResponse)

QueryActiveValidatorsRequest = _reflection.GeneratedProtocolMessageType('QueryActiveValidatorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYACTIVEVALIDATORSREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryActiveValidatorsRequest)
  })
_sym_db.RegisterMessage(QueryActiveValidatorsRequest)

QueryActiveValidatorsResponse = _reflection.GeneratedProtocolMessageType('QueryActiveValidatorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYACTIVEVALIDATORSRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryActiveValidatorsResponse)
  })
_sym_db.RegisterMessage(QueryActiveValidatorsResponse)

QueryRequestSearchRequest = _reflection.GeneratedProtocolMessageType('QueryRequestSearchRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTSEARCHREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestSearchRequest)
  })
_sym_db.RegisterMessage(QueryRequestSearchRequest)

QueryRequestSearchResponse = _reflection.GeneratedProtocolMessageType('QueryRequestSearchResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTSEARCHRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestSearchResponse)
  })
_sym_db.RegisterMessage(QueryRequestSearchResponse)

QueryRequestPriceRequest = _reflection.GeneratedProtocolMessageType('QueryRequestPriceRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTPRICEREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestPriceRequest)
  })
_sym_db.RegisterMessage(QueryRequestPriceRequest)

QueryRequestPriceResponse = _reflection.GeneratedProtocolMessageType('QueryRequestPriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTPRICERESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestPriceResponse)
  })
_sym_db.RegisterMessage(QueryRequestPriceResponse)

QueryRequestVerificationRequest = _reflection.GeneratedProtocolMessageType('QueryRequestVerificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTVERIFICATIONREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestVerificationRequest)
  })
_sym_db.RegisterMessage(QueryRequestVerificationRequest)

QueryRequestVerificationResponse = _reflection.GeneratedProtocolMessageType('QueryRequestVerificationResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTVERIFICATIONRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestVerificationResponse)
  })
_sym_db.RegisterMessage(QueryRequestVerificationResponse)

QueryRequestPoolRequest = _reflection.GeneratedProtocolMessageType('QueryRequestPoolRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTPOOLREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestPoolRequest)
  })
_sym_db.RegisterMessage(QueryRequestPoolRequest)

QueryRequestPoolResponse = _reflection.GeneratedProtocolMessageType('QueryRequestPoolResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTPOOLRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestPoolResponse)
  })
_sym_db.RegisterMessage(QueryRequestPoolResponse)


DESCRIPTOR._options = None
_QUERYREQUESTRESPONSE.fields_by_name['reports']._options = None
_QUERYPENDINGREQUESTSRESPONSE.fields_by_name['request_ids']._options = None
_QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
_QUERYREQUESTPOOLRESPONSE.fields_by_name['balance']._options = None

_QUERY = _descriptor.ServiceDescriptor(
  name='Query',
  full_name='oracle.v1.Query',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2199,
  serialized_end=4039,
  methods=[
  _descriptor.MethodDescriptor(
    name='Counts',
    full_name='oracle.v1.Query.Counts',
    index=0,
    containing_service=None,
    input_type=_QUERYCOUNTSREQUEST,
    output_type=_QUERYCOUNTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/oracle/v1/counts',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Data',
    full_name='oracle.v1.Query.Data',
    index=1,
    containing_service=None,
    input_type=_QUERYDATAREQUEST,
    output_type=_QUERYDATARESPONSE,
    serialized_options=b'\202\323\344\223\002\035\022\033/oracle/v1/data/{data_hash}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DataSource',
    full_name='oracle.v1.Query.DataSource',
    index=2,
    containing_service=None,
    input_type=_QUERYDATASOURCEREQUEST,
    output_type=_QUERYDATASOURCERESPONSE,
    serialized_options=b'\202\323\344\223\002*\022(/oracle/v1/data_sources/{data_source_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OracleScript',
    full_name='oracle.v1.Query.OracleScript',
    index=3,
    containing_service=None,
    input_type=_QUERYORACLESCRIPTREQUEST,
    output_type=_QUERYORACLESCRIPTRESPONSE,
    serialized_options=b'\202\323\344\223\002.\022,/oracle/v1/oracle_scripts/{oracle_script_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Request',
    full_name='oracle.v1.Query.Request',
    index=4,
    containing_service=None,
    input_type=_QUERYREQUESTREQUEST,
    output_type=_QUERYREQUESTRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /oracle/v1/requests/{request_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PendingRequests',
    full_name='oracle.v1.Query.PendingRequests',
    index=5,
    containing_service=None,
    input_type=_QUERYPENDINGREQUESTSREQUEST,
    output_type=_QUERYPENDINGREQUESTSRESPONSE,
    serialized_options=b'\202\323\344\223\0021\022//oracle/v1/pending_requests/{validator_address}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Validator',
    full_name='oracle.v1.Query.Validator',
    index=6,
    containing_service=None,
    input_type=_QUERYVALIDATORREQUEST,
    output_type=_QUERYVALIDATORRESPONSE,
    serialized_options=b'\202\323\344\223\002+\022)/oracle/v1/validators/{validator_address}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Reporters',
    full_name='oracle.v1.Query.Reporters',
    index=7,
    containing_service=None,
    input_type=_QUERYREPORTERSREQUEST,
    output_type=_QUERYREPORTERSRESPONSE,
    serialized_options=b'\202\323\344\223\002*\022(/oracle/v1/reporters/{validator_address}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ActiveValidators',
    full_name='oracle.v1.Query.ActiveValidators',
    index=8,
    containing_service=None,
    input_type=_QUERYACTIVEVALIDATORSREQUEST,
    output_type=_QUERYACTIVEVALIDATORSRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\022\034/oracle/v1/active_validators',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Params',
    full_name='oracle.v1.Query.Params',
    index=9,
    containing_service=None,
    input_type=_QUERYPARAMSREQUEST,
    output_type=_QUERYPARAMSRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/oracle/v1/params',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestSearch',
    full_name='oracle.v1.Query.RequestSearch',
    index=10,
    containing_service=None,
    input_type=_QUERYREQUESTSEARCHREQUEST,
    output_type=_QUERYREQUESTSEARCHRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/oracle/v1/request_search',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestPrice',
    full_name='oracle.v1.Query.RequestPrice',
    index=11,
    containing_service=None,
    input_type=_QUERYREQUESTPRICEREQUEST,
    output_type=_QUERYREQUESTPRICERESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/oracle/v1/request_prices',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestVerification',
    full_name='oracle.v1.Query.RequestVerification',
    index=12,
    containing_service=None,
    input_type=_QUERYREQUESTVERIFICATIONREQUEST,
    output_type=_QUERYREQUESTVERIFICATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/oracle/v1/verify_request',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestPool',
    full_name='oracle.v1.Query.RequestPool',
    index=13,
    containing_service=None,
    input_type=_QUERYREQUESTPOOLREQUEST,
    output_type=_QUERYREQUESTPOOLRESPONSE,
    serialized_options=b'\202\323\344\223\002>\022</oracle/v1/request_pool/{request_key}/{port_id}/{channel_id}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUERY)

DESCRIPTOR.services_by_name['Query'] = _QUERY

# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ClientState:grpc.UnaryUnaryMultiCallable[
        global___QueryClientStateRequest,
        global___QueryClientStateResponse] = ...

    ClientStates:grpc.UnaryUnaryMultiCallable[
        global___QueryClientStatesRequest,
        global___QueryClientStatesResponse] = ...

    ConsensusState:grpc.UnaryUnaryMultiCallable[
        global___QueryConsensusStateRequest,
        global___QueryConsensusStateResponse] = ...

    ConsensusStates:grpc.UnaryUnaryMultiCallable[
        global___QueryConsensusStatesRequest,
        global___QueryConsensusStatesResponse] = ...

    ClientParams:grpc.UnaryUnaryMultiCallable[
        global___QueryClientParamsRequest,
        global___QueryClientParamsResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ClientState(self,
        request: global___QueryClientStateRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryClientStateResponse: ...

    @abc.abstractmethod
    def ClientStates(self,
        request: global___QueryClientStatesRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryClientStatesResponse: ...

    @abc.abstractmethod
    def ConsensusState(self,
        request: global___QueryConsensusStateRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryConsensusStateResponse: ...

    @abc.abstractmethod
    def ConsensusStates(self,
        request: global___QueryConsensusStatesRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryConsensusStatesResponse: ...

    @abc.abstractmethod
    def ClientParams(self,
        request: global___QueryClientParamsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryClientParamsResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class VoteOption(metaclass=_VoteOption):
    V = typing.NewType('V', builtins.int)

global___VoteOption = VoteOption

VOTE_OPTION_UNSPECIFIED = VoteOption.V(0)
VOTE_OPTION_YES = VoteOption.V(1)
VOTE_OPTION_ABSTAIN = VoteOption.V(2)
VOTE_OPTION_NO = VoteOption.V(3)
VOTE_OPTION_NO_WITH_VETO = VoteOption.V(4)

class _VoteOption(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[VoteOption.V], builtins.type):  # type: ignore
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    VOTE_OPTION_UNSPECIFIED = VoteOption.V(0)
    VOTE_OPTION_YES = VoteOption.V(1)
    VOTE_OPTION_ABSTAIN = VoteOption.V(2)
    VOTE_OPTION_NO = VoteOption.V(3)
    VOTE_OPTION_NO_WITH_VETO = VoteOption.V(4)

class ProposalStatus(metaclass=_ProposalStatus):
    V = typing.NewType('V', builtins.int)

global___ProposalStatus = ProposalStatus

PROPOSAL_STATUS_UNSPECIFIED = ProposalStatus.V(0)
PROPOSAL_STATUS_DEPOSIT_PERIOD = ProposalStatus.V(1)
PROPOSAL_STATUS_VOTING_PERIOD = ProposalStatus.V(2)
PROPOSAL_STATUS_PASSED = ProposalStatus.V(3)
PROPOSAL_STATUS_REJECTED = ProposalStatus.V(4)
PROPOSAL_STATUS_FAILED = ProposalStatus.V(5)

class _ProposalStatus(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ProposalStatus.V], builtins.type):  # type: ignore
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    PROPOSAL_STATUS_UNSPECIFIED = ProposalStatus.V(0)
    PROPOSAL_STATUS_DEPOSIT_PERIOD = ProposalStatus.V(1)
    PROPOSAL_STATUS_VOTING_PERIOD = ProposalStatus.V(2)
    PROPOSAL_STATUS_PASSED = ProposalStatus.V(3)
    PROPOSAL_STATUS_REJECTED = ProposalStatus.V(4)
    PROPOSAL_STATUS_FAILED = ProposalStatus.V(5)

class TextProposal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    title: typing.Text = ...
    description: typing.Text = ...

    def __init__(self,
        *,
        title : typing.Text = ...,
        description : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"description",b"description",u"title",b"title"]) -> None: ...
global___TextProposal = TextProposal

class Deposit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    DEPOSITOR_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...
    depositor: typing.Text = ...

    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        depositor : typing.Text = ...,
        amount : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"amount",b"amount",u"depositor",b"depositor",u"proposal_id",b"proposal_id"]) -> None: ...
global___Deposit = Deposit

class Proposal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    FINAL_TALLY_RESULT_FIELD_NUMBER: builtins.int
    SUBMIT_TIME_FIELD_NUMBER: builtins.int
    DEPOSIT_END_TIME_FIELD_NUMBER: builtins.int
    TOTAL_DEPOSIT_FIELD_NUMBER: builtins.int
    VOTING_START_TIME_FIELD_NUMBER: builtins.int
    VOTING_END_TIME_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...
    status: global___ProposalStatus.V = ...

    @property
    def content(self) -> google.protobuf.any_pb2.Any: ...

    @property
    def final_tally_result(self) -> global___TallyResult: ...

    @property
    def submit_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    @property
    def deposit_end_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    @property
    def total_deposit(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    @property
    def voting_start_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    @property
    def voting_end_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        content : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        status : global___ProposalStatus.V = ...,
        final_tally_result : typing.Optional[global___TallyResult] = ...,
        submit_time : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        deposit_end_time : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        total_deposit : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        voting_start_time : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        voting_end_time : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"content",b"content",u"deposit_end_time",b"deposit_end_time",u"final_tally_result",b"final_tally_result",u"submit_time",b"submit_time",u"voting_end_time",b"voting_end_time",u"voting_start_time",b"voting_start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"content",b"content",u"deposit_end_time",b"deposit_end_time",u"final_tally_result",b"final_tally_result",u"proposal_id",b"proposal_id",u"status",b"status",u"submit_time",b"submit_time",u"total_deposit",b"total_deposit",u"voting_end_time",b"voting_end_time",u"voting_start_time",b"voting_start_time"]) -> None: ...
global___Proposal = Proposal

class TallyResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    YES_FIELD_NUMBER: builtins.int
    ABSTAIN_FIELD_NUMBER: builtins.int
    NO_FIELD_NUMBER: builtins.int
    NO_WITH_VETO_FIELD_NUMBER: builtins.int
    yes: typing.Text = ...
    abstain: typing.Text = ...
    no: typing.Text = ...
    no_with_veto: typing.Text = ...

    def __init__(self,
        *,
        yes : typing.Text = ...,
        abstain : typing.Text = ...,
        no : typing.Text = ...,
        no_with_veto : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"abstain",b"abstain",u"no",b"no",u"no_with_veto",b"no_with_veto",u"yes",b"yes"]) -> None: ...
global___TallyResult = TallyResult

class Vote(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    VOTER_FIELD_NUMBER: builtins.int
    OPTION_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...
    voter: typing.Text = ...
    option: global___VoteOption.V = ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        voter : typing.Text = ...,
        option : global___VoteOption.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"option",b"option",u"proposal_id",b"proposal_id",u"voter",b"voter"]) -> None: ...
global___Vote = Vote

class DepositParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MIN_DEPOSIT_FIELD_NUMBER: builtins.int
    MAX_DEPOSIT_PERIOD_FIELD_NUMBER: builtins.int

    @property
    def min_deposit(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    @property
    def max_deposit_period(self) -> google.protobuf.duration_pb2.Duration: ...

    def __init__(self,
        *,
        min_deposit : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        max_deposit_period : typing.Optional[google.protobuf.duration_pb2.Duration] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"max_deposit_period",b"max_deposit_period"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"max_deposit_period",b"max_deposit_period",u"min_deposit",b"min_deposit"]) -> None: ...
global___DepositParams = DepositParams

class VotingParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VOTING_PERIOD_FIELD_NUMBER: builtins.int

    @property
    def voting_period(self) -> google.protobuf.duration_pb2.Duration: ...

    def __init__(self,
        *,
        voting_period : typing.Optional[google.protobuf.duration_pb2.Duration] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"voting_period",b"voting_period"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"voting_period",b"voting_period"]) -> None: ...
global___VotingParams = VotingParams

class TallyParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    QUORUM_FIELD_NUMBER: builtins.int
    THRESHOLD_FIELD_NUMBER: builtins.int
    VETO_THRESHOLD_FIELD_NUMBER: builtins.int
    quorum: builtins.bytes = ...
    threshold: builtins.bytes = ...
    veto_threshold: builtins.bytes = ...

    def __init__(self,
        *,
        quorum : builtins.bytes = ...,
        threshold : builtins.bytes = ...,
        veto_threshold : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"quorum",b"quorum",u"threshold",b"threshold",u"veto_threshold",b"veto_threshold"]) -> None: ...
global___TallyParams = TallyParams



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.query.v1beta1.pagination_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryEvidenceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EVIDENCE_HASH_FIELD_NUMBER: builtins.int
    evidence_hash: builtins.bytes = ...

    def __init__(self,
        *,
        evidence_hash : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"evidence_hash",b"evidence_hash"]) -> None: ...
global___QueryEvidenceRequest = QueryEvidenceRequest

class QueryEvidenceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EVIDENCE_FIELD_NUMBER: builtins.int

    @property
    def evidence(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        evidence : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"evidence",b"evidence"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"evidence",b"evidence"]) -> None: ...
global___QueryEvidenceResponse = QueryEvidenceResponse

class QueryAllEvidenceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> None: ...
global___QueryAllEvidenceRequest = QueryAllEvidenceRequest

class QueryAllEvidenceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EVIDENCE_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def evidence(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    def __init__(self,
        *,
        evidence : typing.Optional[typing.Iterable[google.protobuf.any_pb2.Any]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"evidence",b"evidence",u"pagination",b"pagination"]) -> None: ...
global___QueryAllEvidenceResponse = QueryAllEvidenceResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/transfer/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.applications.transfer.v1 import transfer_pb2 as ibc_dot_applications_dot_transfer_dot_v1_dot_transfer__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ibc/applications/transfer/v1/genesis.proto',
  package='ibc.applications.transfer.v1',
  syntax='proto3',
  serialized_options=b'Z>github.com/cosmos/cosmos-sdk/x/ibc/applications/transfer/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*ibc/applications/transfer/v1/genesis.proto\x12\x1cibc.applications.transfer.v1\x1a\x14gogoproto/gogo.proto\x1a+ibc/applications/transfer/v1/transfer.proto\"\xd6\x01\n\x0cGenesisState\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12\x65\n\x0c\x64\x65nom_traces\x18\x02 \x03(\x0b\x32(.ibc.applications.transfer.v1.DenomTraceB%\xaa\xdf\x1f\x06Traces\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:\"denom_traces\"\x12:\n\x06params\x18\x03 \x01(\x0b\x32$.ibc.applications.transfer.v1.ParamsB\x04\xc8\xde\x1f\x00\x42@Z>github.com/cosmos/cosmos-sdk/x/ibc/applications/transfer/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,ibc_dot_applications_dot_transfer_dot_v1_dot_transfer__pb2.DESCRIPTOR,])




_GENESISSTATE = _descriptor.Descriptor(
  name='GenesisState',
  full_name='ibc.applications.transfer.v1.GenesisState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_id', full_name='ibc.applications.transfer.v1.GenesisState.port_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\016yaml:\"port_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denom_traces', full_name='ibc.applications.transfer.v1.GenesisState.denom_traces', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\252\337\037\006Traces\310\336\037\000\362\336\037\023yaml:\"denom_traces\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='ibc.applications.transfer.v1.GenesisState.params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=358,
)

_GENESISSTATE.fields_by_name['denom_traces'].message_type = ibc_dot_applications_dot_transfer_dot_v1_dot_transfer__pb2._DENOMTRACE
_GENESISSTATE.fields_by_name['params'].message_type = ibc_dot_applications_dot_transfer_dot_v1_dot_transfer__pb2._PARAMS
DESCRIPTOR.message_types_by_name['GenesisState'] = _GENESISSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'ibc.applications.transfer.v1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:ibc.applications.transfer.v1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)


DESCRIPTOR._options = None
_GENESISSTATE.fields_by_name['port_id']._options = None
_GENESISSTATE.fields_by_name['denom_traces']._options = None
_GENESISSTATE.fields_by_name['params']._options = None
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import oracle.v1.oracle_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARAMS_FIELD_NUMBER: builtins.int
    DATA_SOURCES_FIELD_NUMBER: builtins.int
    ORACLE_SCRIPTS_FIELD_NUMBER: builtins.int
    REPORTERS_FIELD_NUMBER: builtins.int

    @property
    def params(self) -> oracle.v1.oracle_pb2.Params: ...

    @property
    def data_sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[oracle.v1.oracle_pb2.DataSource]: ...

    @property
    def oracle_scripts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[oracle.v1.oracle_pb2.OracleScript]: ...

    @property
    def reporters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[oracle.v1.oracle_pb2.ReportersPerValidator]: ...

    def __init__(self,
        *,
        params : typing.Optional[oracle.v1.oracle_pb2.Params] = ...,
        data_sources : typing.Optional[typing.Iterable[oracle.v1.oracle_pb2.DataSource]] = ...,
        oracle_scripts : typing.Optional[typing.Iterable[oracle.v1.oracle_pb2.OracleScript]] = ...,
        reporters : typing.Optional[typing.Iterable[oracle.v1.oracle_pb2.ReportersPerValidator]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data_sources",b"data_sources",u"oracle_scripts",b"oracle_scripts",u"params",b"params",u"reporters",b"reporters"]) -> None: ...
global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import ibc.core.channel.v1.channel_pb2
import ibc.core.connection.v1.connection_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DataType(metaclass=_DataType):
    V = typing.NewType('V', builtins.int)

global___DataType = DataType

DATA_TYPE_UNINITIALIZED_UNSPECIFIED = DataType.V(0)
DATA_TYPE_CLIENT_STATE = DataType.V(1)
DATA_TYPE_CONSENSUS_STATE = DataType.V(2)
DATA_TYPE_CONNECTION_STATE = DataType.V(3)
DATA_TYPE_CHANNEL_STATE = DataType.V(4)
DATA_TYPE_PACKET_COMMITMENT = DataType.V(5)
DATA_TYPE_PACKET_ACKNOWLEDGEMENT = DataType.V(6)
DATA_TYPE_PACKET_RECEIPT_ABSENCE = DataType.V(7)
DATA_TYPE_NEXT_SEQUENCE_RECV = DataType.V(8)
DATA_TYPE_HEADER = DataType.V(9)

class _DataType(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DataType.V], builtins.type):  # type: ignore
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    DATA_TYPE_UNINITIALIZED_UNSPECIFIED = DataType.V(0)
    DATA_TYPE_CLIENT_STATE = DataType.V(1)
    DATA_TYPE_CONSENSUS_STATE = DataType.V(2)
    DATA_TYPE_CONNECTION_STATE = DataType.V(3)
    DATA_TYPE_CHANNEL_STATE = DataType.V(4)
    DATA_TYPE_PACKET_COMMITMENT = DataType.V(5)
    DATA_TYPE_PACKET_ACKNOWLEDGEMENT = DataType.V(6)
    DATA_TYPE_PACKET_RECEIPT_ABSENCE = DataType.V(7)
    DATA_TYPE_NEXT_SEQUENCE_RECV = DataType.V(8)
    DATA_TYPE_HEADER = DataType.V(9)

class ClientState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SEQUENCE_FIELD_NUMBER: builtins.int
    FROZEN_SEQUENCE_FIELD_NUMBER: builtins.int
    CONSENSUS_STATE_FIELD_NUMBER: builtins.int
    ALLOW_UPDATE_AFTER_PROPOSAL_FIELD_NUMBER: builtins.int
    sequence: builtins.int = ...
    frozen_sequence: builtins.int = ...
    allow_update_after_proposal: builtins.bool = ...

    @property
    def consensus_state(self) -> global___ConsensusState: ...

    def __init__(self,
        *,
        sequence : builtins.int = ...,
        frozen_sequence : builtins.int = ...,
        consensus_state : typing.Optional[global___ConsensusState] = ...,
        allow_update_after_proposal : builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"consensus_state",b"consensus_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"allow_update_after_proposal",b"allow_update_after_proposal",u"consensus_state",b"consensus_state",u"frozen_sequence",b"frozen_sequence",u"sequence",b"sequence"]) -> None: ...
global___ClientState = ClientState

class ConsensusState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    DIVERSIFIER_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    diversifier: typing.Text = ...
    timestamp: builtins.int = ...

    @property
    def public_key(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        public_key : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        diversifier : typing.Text = ...,
        timestamp : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"public_key",b"public_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"diversifier",b"diversifier",u"public_key",b"public_key",u"timestamp",b"timestamp"]) -> None: ...
global___ConsensusState = ConsensusState

class Header(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SEQUENCE_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    NEW_PUBLIC_KEY_FIELD_NUMBER: builtins.int
    NEW_DIVERSIFIER_FIELD_NUMBER: builtins.int
    sequence: builtins.int = ...
    timestamp: builtins.int = ...
    signature: builtins.bytes = ...
    new_diversifier: typing.Text = ...

    @property
    def new_public_key(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        sequence : builtins.int = ...,
        timestamp : builtins.int = ...,
        signature : builtins.bytes = ...,
        new_public_key : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        new_diversifier : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"new_public_key",b"new_public_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"new_diversifier",b"new_diversifier",u"new_public_key",b"new_public_key",u"sequence",b"sequence",u"signature",b"signature",u"timestamp",b"timestamp"]) -> None: ...
global___Header = Header

class Misbehaviour(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    SIGNATURE_ONE_FIELD_NUMBER: builtins.int
    SIGNATURE_TWO_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...
    sequence: builtins.int = ...

    @property
    def signature_one(self) -> global___SignatureAndData: ...

    @property
    def signature_two(self) -> global___SignatureAndData: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        sequence : builtins.int = ...,
        signature_one : typing.Optional[global___SignatureAndData] = ...,
        signature_two : typing.Optional[global___SignatureAndData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"signature_one",b"signature_one",u"signature_two",b"signature_two"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"sequence",b"sequence",u"signature_one",b"signature_one",u"signature_two",b"signature_two"]) -> None: ...
global___Misbehaviour = Misbehaviour

class SignatureAndData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SIGNATURE_FIELD_NUMBER: builtins.int
    DATA_TYPE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    signature: builtins.bytes = ...
    data_type: global___DataType.V = ...
    data: builtins.bytes = ...
    timestamp: builtins.int = ...

    def __init__(self,
        *,
        signature : builtins.bytes = ...,
        data_type : global___DataType.V = ...,
        data : builtins.bytes = ...,
        timestamp : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"data_type",b"data_type",u"signature",b"signature",u"timestamp",b"timestamp"]) -> None: ...
global___SignatureAndData = SignatureAndData

class TimestampedSignatureData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SIGNATURE_DATA_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    signature_data: builtins.bytes = ...
    timestamp: builtins.int = ...

    def __init__(self,
        *,
        signature_data : builtins.bytes = ...,
        timestamp : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"signature_data",b"signature_data",u"timestamp",b"timestamp"]) -> None: ...
global___TimestampedSignatureData = TimestampedSignatureData

class SignBytes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SEQUENCE_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    DIVERSIFIER_FIELD_NUMBER: builtins.int
    DATA_TYPE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    sequence: builtins.int = ...
    timestamp: builtins.int = ...
    diversifier: typing.Text = ...
    data_type: global___DataType.V = ...
    data: builtins.bytes = ...

    def __init__(self,
        *,
        sequence : builtins.int = ...,
        timestamp : builtins.int = ...,
        diversifier : typing.Text = ...,
        data_type : global___DataType.V = ...,
        data : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"data_type",b"data_type",u"diversifier",b"diversifier",u"sequence",b"sequence",u"timestamp",b"timestamp"]) -> None: ...
global___SignBytes = SignBytes

class HeaderData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NEW_PUB_KEY_FIELD_NUMBER: builtins.int
    NEW_DIVERSIFIER_FIELD_NUMBER: builtins.int
    new_diversifier: typing.Text = ...

    @property
    def new_pub_key(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        new_pub_key : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        new_diversifier : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"new_pub_key",b"new_pub_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"new_diversifier",b"new_diversifier",u"new_pub_key",b"new_pub_key"]) -> None: ...
global___HeaderData = HeaderData

class ClientStateData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PATH_FIELD_NUMBER: builtins.int
    CLIENT_STATE_FIELD_NUMBER: builtins.int
    path: builtins.bytes = ...

    @property
    def client_state(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        path : builtins.bytes = ...,
        client_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"client_state",b"client_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_state",b"client_state",u"path",b"path"]) -> None: ...
global___ClientStateData = ClientStateData

class ConsensusStateData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PATH_FIELD_NUMBER: builtins.int
    CONSENSUS_STATE_FIELD_NUMBER: builtins.int
    path: builtins.bytes = ...

    @property
    def consensus_state(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        path : builtins.bytes = ...,
        consensus_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"consensus_state",b"consensus_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"consensus_state",b"consensus_state",u"path",b"path"]) -> None: ...
global___ConsensusStateData = ConsensusStateData

class ConnectionStateData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PATH_FIELD_NUMBER: builtins.int
    CONNECTION_FIELD_NUMBER: builtins.int
    path: builtins.bytes = ...

    @property
    def connection(self) -> ibc.core.connection.v1.connection_pb2.ConnectionEnd: ...

    def __init__(self,
        *,
        path : builtins.bytes = ...,
        connection : typing.Optional[ibc.core.connection.v1.connection_pb2.ConnectionEnd] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"connection",b"connection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"connection",b"connection",u"path",b"path"]) -> None: ...
global___ConnectionStateData = ConnectionStateData

class ChannelStateData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PATH_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    path: builtins.bytes = ...

    @property
    def channel(self) -> ibc.core.channel.v1.channel_pb2.Channel: ...

    def __init__(self,
        *,
        path : builtins.bytes = ...,
        channel : typing.Optional[ibc.core.channel.v1.channel_pb2.Channel] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"channel",b"channel"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel",b"channel",u"path",b"path"]) -> None: ...
global___ChannelStateData = ChannelStateData

class PacketCommitmentData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PATH_FIELD_NUMBER: builtins.int
    COMMITMENT_FIELD_NUMBER: builtins.int
    path: builtins.bytes = ...
    commitment: builtins.bytes = ...

    def __init__(self,
        *,
        path : builtins.bytes = ...,
        commitment : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commitment",b"commitment",u"path",b"path"]) -> None: ...
global___PacketCommitmentData = PacketCommitmentData

class PacketAcknowledgementData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PATH_FIELD_NUMBER: builtins.int
    ACKNOWLEDGEMENT_FIELD_NUMBER: builtins.int
    path: builtins.bytes = ...
    acknowledgement: builtins.bytes = ...

    def __init__(self,
        *,
        path : builtins.bytes = ...,
        acknowledgement : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"acknowledgement",b"acknowledgement",u"path",b"path"]) -> None: ...
global___PacketAcknowledgementData = PacketAcknowledgementData

class PacketReceiptAbsenceData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PATH_FIELD_NUMBER: builtins.int
    path: builtins.bytes = ...

    def __init__(self,
        *,
        path : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"path",b"path"]) -> None: ...
global___PacketReceiptAbsenceData = PacketReceiptAbsenceData

class NextSequenceRecvData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PATH_FIELD_NUMBER: builtins.int
    NEXT_SEQ_RECV_FIELD_NUMBER: builtins.int
    path: builtins.bytes = ...
    next_seq_recv: builtins.int = ...

    def __init__(self,
        *,
        path : builtins.bytes = ...,
        next_seq_recv : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"next_seq_recv",b"next_seq_recv",u"path",b"path"]) -> None: ...
global___NextSequenceRecvData = NextSequenceRecvData



import pytest
from google.protobuf.any_pb2 import Any

from pyband.exceptions import EmptyMsgError, UndefinedError, ValueTooLargeError
from pyband.transaction import Transaction
from pyband.wallet import PrivateKey

from pyband.proto.cosmos.base.v1beta1.coin_pb2 import Coin
from pyband.proto.cosmos.tx.v1beta1.tx_pb2 import Fee, SignDoc
from pyband.proto.cosmos.auth.v1beta1.query_pb2 import QueryAccountRequest, QueryAccountResponse
from pyband.proto.oracle.v1.tx_pb2 import MsgRequestData

# Servicers
from pyband.proto.cosmos.auth.v1beta1.query_pb2_grpc import QueryServicer as QueryServicerBase


MNEMONIC = "s"
PRIVATE_KEY = PrivateKey.from_mnemonic(MNEMONIC)
PUBLIC_KEY = PRIVATE_KEY.to_public_key()
ADDRESS = PUBLIC_KEY.to_address()
SENDER = ADDRESS.to_acc_bech32()


class QueryServicer(QueryServicerBase):

    def Account(self, request: QueryAccountRequest, context):
        return QueryAccountResponse(
            account=Any(
                type_url="/cosmos.auth.v1beta1.BaseAccount",
                value=b"\n+band1z2hwz2vn6ardpjzgfx2k3wh2zglknwavhw3v2r\022F\n\037/cosmos.crypto.secp256k1.PubKey\022#\n!\002\243\357\354\271\2712\330H\300F\342suhP\357^!\007\244&\365\t\314\274\312\034~\240\004A\341\030h \010",
            )
        )


@pytest.fixture(scope="module")
def pyband_client(_grpc_server, grpc_addr):
    from pyband.proto.cosmos.auth.v1beta1.query_pb2_grpc import add_QueryServicer_to_server as add_cosmos_query

    add_cosmos_query(QueryServicer(), _grpc_server)

    _grpc_server.add_insecure_port(grpc_addr)
    _grpc_server.start()

    from pyband.client import Client

    yield Client(grpc_addr)
    _grpc_server.stop(grace=None)


def test_get_sign_doc_success():
    msg = MsgRequestData(
        oracle_script_id=1,
        calldata=bytes.fromhex("000000034254430000000000000001"),
        ask_count=4,
        min_count=3,
        client_id="from_pyband",
        fee_limit=[Coin(amount="100", denom="uband")],
        prepare_gas=30000,
        execute_gas=50000,
        sender="band13eznuehmqzd3r84fkxu8wklxl22r2qfmtlth8c",
    )

    t = Transaction().with_messages(msg).with_account_num(100).with_sequence(30).with_chain_id("bandchain")
    assert t.get_sign_doc(PUBLIC_KEY) == SignDoc(
        body_bytes=b"\n\204\001\n\031/oracle.v1.MsgRequestData\022g\010\001\022\017\000\000\000\003BTC\000\000\000\000\000\000\000\001\030\004 \003*\013from_pyband2\014\n\005uband\022\0031008\260\352\001@\320\206\003J+band13eznuehmqzd3r84fkxu8wklxl22r2qfmtlth8c",
        auth_info_bytes=b"\nP\nF\n\037/cosmos.crypto.secp256k1.PubKey\022#\n!\003\376p\213\332fRO\322\306\274\351\006\202\343\205U\250Q\340=*\356Ob\233\005\336\220\365\036\331\274\022\004\n\002\010\001\030\036\022\004\020\300\232\014",
        chain_id="bandchain",
        account_number=100,
    )

def test_get_sign_doc_no_public_key_success():
    msg = MsgRequestData(
        oracle_script_id=1,
        calldata=bytes.fromhex("000000034254430000000000000001"),
        ask_count=4,
        min_count=3,
        client_id="from_pyband",
        fee_limit=[Coin(amount="100", denom="uband")],
        prepare_gas=30000,
        execute_gas=50000,
        sender="band13eznuehmqzd3r84fkxu8wklxl22r2qfmtlth8c",
    )

    t = Transaction().with_messages(msg).with_account_num(100).with_sequence(30).with_chain_id("bandchain")
    assert t.get_sign_doc() == SignDoc(
        body_bytes=b"\n\204\001\n\031/oracle.v1.MsgRequestData\022g\010\001\022\017\000\000\000\003BTC\000\000\000\000\000\000\000\001\030\004 \003*\013from_pyband2\014\n\005uband\022\0031008\260\352\001@\320\206\003J+band13eznuehmqzd3r84fkxu8wklxl22r2qfmtlth8c",
        auth_info_bytes=b"\n\010\022\004\n\002\010\001\030\036\022\004\020\300\232\014",
        chain_id="bandchain",
        account_number=100,
    )

def test_get_sign_data_with_sender_success(pyband_client):
    msg = MsgRequestData(
        oracle_script_id=1,
        calldata=bytes.fromhex("000000034254430000000000000001"),
        ask_count=4,
        min_count=3,
        client_id="from_pyband",
        fee_limit=[Coin(amount="100", denom="uband")],
        prepare_gas=30000,
        execute_gas=50000,
        sender="band13eznuehmqzd3r84fkxu8wklxl22r2qfmtlth8c",
    )
    fee = [Coin(amount="0", denom="uband")]

    t = (
        Transaction()
        .with_messages(msg)
        .with_sender(pyband_client, "band13eznuehmqzd3r84fkxu8wklxl22r2qfmtlth8c")
        .with_chain_id("bandchain")
        .with_gas(50000)
        .with_fee(fee)
    )
    assert t.get_sign_doc(PUBLIC_KEY) == SignDoc(
        body_bytes=b"\n\204\001\n\031/oracle.v1.MsgRequestData\022g\010\001\022\017\000\000\000\003BTC\000\000\000\000\000\000\000\001\030\004 \003*\013from_pyband2\014\n\005uband\022\0031008\260\352\001@\320\206\003J+band13eznuehmqzd3r84fkxu8wklxl22r2qfmtlth8c",
        auth_info_bytes=b"\nP\nF\n\037/cosmos.crypto.secp256k1.PubKey\022#\n!\003\376p\213\332fRO\322\306\274\351\006\202\343\205U\250Q\340=*\356Ob\233\005\336\220\365\036\331\274\022\004\n\002\010\001\030\010\022\020\n\n\n\005uband\022\0010\020\320\206\003",
        chain_id="bandchain",
        account_number=104,
    )

def test_create_transaction_with_sender_fail(pyband_client):
    with pytest.raises(EmptyMsgError, match="messsage is empty, please use with_messages at least 1 message"):
        t = Transaction().with_sender(pyband_client, "band13eznuehmqzd3r84fkxu8wklxl22r2qfmtlth8c")


def test_get_sign_doc_msg_empty():
    t = Transaction().with_account_num(100).with_sequence(30).with_chain_id("bandchain")
    with pytest.raises(EmptyMsgError, match="message is empty"):
        t.get_sign_doc(PUBLIC_KEY)


def test_get_sign_doc_account_num_fail():
    msg = MsgRequestData(
        oracle_script_id=1,
        calldata=bytes.fromhex("000000034254430000000000000001"),
        ask_count=4,
        min_count=3,
        client_id="from_pyband",
        fee_limit=[Coin(amount="100", denom="uband")],
        prepare_gas=30000,
        execute_gas=50000,
        sender="band13eznuehmqzd3r84fkxu8wklxl22r2qfmtlth8c",
    )

    t = Transaction().with_messages(msg).with_sequence(30).with_chain_id("bandchain")
    with pytest.raises(UndefinedError, match="account_num should be defined"):
        t.get_sign_doc(PUBLIC_KEY)


def test_get_sign_doc_sequence_undefined():
    msg = MsgRequestData(
        oracle_script_id=1,
        calldata=bytes.fromhex("000000034254430000000000000001"),
        ask_count=4,
        min_count=3,
        client_id="from_pyband",
        fee_limit=[Coin(amount="100", denom="uband")],
        prepare_gas=30000,
        execute_gas=50000,
        sender="band13eznuehmqzd3r84fkxu8wklxl22r2qfmtlth8c",
    )

    t = Transaction().with_messages(msg).with_account_num(100).with_chain_id("bandchain")
    with pytest.raises(UndefinedError, match="sequence should be defined"):
        t.get_sign_doc(PUBLIC_KEY)


def test_get_sign_doc_chain_id_undefined():
    msg = MsgRequestData(
        oracle_script_id=1,
        calldata=bytes.fromhex("000000034254430000000000000001"),
        ask_count=4,
        min_count=3,
        client_id="from_pyband",
        fee_limit=[Coin(amount="100", denom="uband")],
        prepare_gas=30000,
        execute_gas=50000,
        sender="band13eznuehmqzd3r84fkxu8wklxl22r2qfmtlth8c",
    )

    t = Transaction().with_messages(msg).with_account_num(100).with_sequence(30)

    with pytest.raises(UndefinedError, match="chain_id should be defined"):
        t.get_sign_doc(PUBLIC_KEY)


def test_invalid_memo():
    msg = MsgRequestData(
        oracle_script_id=1,
        calldata=bytes.fromhex("000000034254430000000000000001"),
        ask_count=4,
        min_count=3,
        client_id="from_pyband",
        fee_limit=[Coin(amount="100", denom="uband")],
        prepare_gas=30000,
        execute_gas=50000,
        sender="band13eznuehmqzd3r84fkxu8wklxl22r2qfmtlth8c",
    )

    t = Transaction().with_messages(msg).with_account_num(100).with_sequence(30).with_chain_id("bandchain")
    with pytest.raises(ValueTooLargeError, match="memo is too large"):
        t.with_memo(
            "This is the longest memo in the world. This is the longest memo in the world. This is the longest memo in the world. This is the longest memo in the world. This is the longest memo in the world. This is the longest memo in the world. This is the longest memo in the world.This is the longest memo in the world. This is the longest memo in the world.This is the longest memo in the world."
        )


def test_get_tx_data_success():
    msg = MsgRequestData(
        oracle_script_id=1,
        calldata=bytes.fromhex("000000034254430000000000000001"),
        ask_count=4,
        min_count=3,
        client_id="from_pyband",
        fee_limit=[Coin(amount="100", denom="uband")],
        prepare_gas=30000,
        execute_gas=50000,
        sender=SENDER,
    )

    t = Transaction().with_messages(msg).with_account_num(100).with_sequence(30).with_chain_id("bandchain")

    sign_doc = t.get_sign_doc(PUBLIC_KEY)
    signature = PRIVATE_KEY.sign(sign_doc.SerializeToString())
    tx_raw_bytes = t.get_tx_data(signature, PUBLIC_KEY)
    assert tx_raw_bytes == b"\n\x87\x01\n\x84\x01\n\x19/oracle.v1.MsgRequestData\x12g\x08\x01\x12\x0f\x00\x00\x00\x03BTC\x00\x00\x00\x00\x00\x00\x00\x01\x18\x04 \x03*\x0bfrom_pyband2\x0c\n\x05uband\x12\x031008\xb0\xea\x01@\xd0\x86\x03J+band1jrhuqrymzt4mnvgw8cvy3s9zhx3jj0dq30qpte\x12X\nP\nF\n\x1f/cosmos.crypto.secp256k1.PubKey\x12#\n!\x03\xfep\x8b\xdafRO\xd2\xc6\xbc\xe9\x06\x82\xe3\x85U\xa8Q\xe0=*\xeeOb\x9b\x05\xde\x90\xf5\x1e\xd9\xbc\x12\x04\n\x02\x08\x01\x18\x1e\x12\x04\x10\xc0\x9a\x0c\x1a@/\xa2\xe7\xb3e\xf8\x13\x7f$\x162q\x11\xbaX\xa0\x93\xbeWeO\xc7~\x0e3\xe5F\xd0\xbd\xf1\xd5\xe1k\xefnxuv\x14l?\x8a3\x06Z_7\x93\xd7\xcc\xbf\xc0\xa2S\xff\xaa\x19\xfd}\xddO\xe3\xd9\xb1"


def test_get_tx_data_tx_raw_bytes_no_public_key_success():
    msg = MsgRequestData(
        oracle_script_id=1,
        calldata=bytes.fromhex("000000034254430000000000000001"),
        ask_count=4,
        min_count=3,
        client_id="from_pyband",
        fee_limit=[Coin(amount="100", denom="uband")],
        prepare_gas=30000,
        execute_gas=50000,
        sender=SENDER,
    )

    t = Transaction().with_messages(msg).with_account_num(100).with_sequence(30).with_chain_id("bandchain")

    sign_doc = t.get_sign_doc(PUBLIC_KEY)
    signature = PRIVATE_KEY.sign(sign_doc.SerializeToString())
    tx_raw_bytes = t.get_tx_data(signature)
    assert tx_raw_bytes == b"\n\x87\x01\n\x84\x01\n\x19/oracle.v1.MsgRequestData\x12g\x08\x01\x12\x0f\x00\x00\x00\x03BTC\x00\x00\x00\x00\x00\x00\x00\x01\x18\x04 \x03*\x0bfrom_pyband2\x0c\n\x05uband\x12\x031008\xb0\xea\x01@\xd0\x86\x03J+band1jrhuqrymzt4mnvgw8cvy3s9zhx3jj0dq30qpte\x12\x10\n\x08\x12\x04\n\x02\x08\x01\x18\x1e\x12\x04\x10\xc0\x9a\x0c\x1a@/\xa2\xe7\xb3e\xf8\x13\x7f$\x162q\x11\xbaX\xa0\x93\xbeWeO\xc7~\x0e3\xe5F\xd0\xbd\xf1\xd5\xe1k\xefnxuv\x14l?\x8a3\x06Z_7\x93\xd7\xcc\xbf\xc0\xa2S\xff\xaa\x19\xfd}\xddO\xe3\xd9\xb1"


def test_get_tx_data_no_public_key_success():
    msg = MsgRequestData(
        oracle_script_id=1,
        calldata=bytes.fromhex("000000034254430000000000000001"),
        ask_count=4,
        min_count=3,
        client_id="from_pyband",
        fee_limit=[Coin(amount="100", denom="uband")],
        prepare_gas=30000,
        execute_gas=50000,
        sender=SENDER,
    )

    t = Transaction().with_messages(msg).with_account_num(100).with_sequence(30).with_chain_id("bandchain")

    sign_doc = t.get_sign_doc()
    signature = PRIVATE_KEY.sign(sign_doc.SerializeToString())
    tx_raw_bytes = t.get_tx_data(signature)
    assert tx_raw_bytes == b"\n\x87\x01\n\x84\x01\n\x19/oracle.v1.MsgRequestData\x12g\x08\x01\x12\x0f\x00\x00\x00\x03BTC\x00\x00\x00\x00\x00\x00\x00\x01\x18\x04 \x03*\x0bfrom_pyband2\x0c\n\x05uband\x12\x031008\xb0\xea\x01@\xd0\x86\x03J+band1jrhuqrymzt4mnvgw8cvy3s9zhx3jj0dq30qpte\x12\x10\n\x08\x12\x04\n\x02\x08\x01\x18\x1e\x12\x04\x10\xc0\x9a\x0c\x1a@\xf3\xb5z\xa4\xea\xc6\x02\xff\\\x862x\x80\xba\xbf\xd8%t\x88X\xddrDY^\"C\xd7\x9c\xf1\xb3\xbe]\xe7Z\x9a\x07\xedX\xf7r\xd4\xf8\x044\xf8\xda\x86\x80(~J\xb8\r\x12\x03\x17\xcb\x9f\xb95\xa4&\xa1"



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class ServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetNodeInfo:grpc.UnaryUnaryMultiCallable[
        global___GetNodeInfoRequest,
        global___GetNodeInfoResponse] = ...

    GetSyncing:grpc.UnaryUnaryMultiCallable[
        global___GetSyncingRequest,
        global___GetSyncingResponse] = ...

    GetLatestBlock:grpc.UnaryUnaryMultiCallable[
        global___GetLatestBlockRequest,
        global___GetLatestBlockResponse] = ...

    GetBlockByHeight:grpc.UnaryUnaryMultiCallable[
        global___GetBlockByHeightRequest,
        global___GetBlockByHeightResponse] = ...

    GetLatestValidatorSet:grpc.UnaryUnaryMultiCallable[
        global___GetLatestValidatorSetRequest,
        global___GetLatestValidatorSetResponse] = ...

    GetValidatorSetByHeight:grpc.UnaryUnaryMultiCallable[
        global___GetValidatorSetByHeightRequest,
        global___GetValidatorSetByHeightResponse] = ...


class ServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetNodeInfo(self,
        request: global___GetNodeInfoRequest,
        context: grpc.ServicerContext,
    ) -> global___GetNodeInfoResponse: ...

    @abc.abstractmethod
    def GetSyncing(self,
        request: global___GetSyncingRequest,
        context: grpc.ServicerContext,
    ) -> global___GetSyncingResponse: ...

    @abc.abstractmethod
    def GetLatestBlock(self,
        request: global___GetLatestBlockRequest,
        context: grpc.ServicerContext,
    ) -> global___GetLatestBlockResponse: ...

    @abc.abstractmethod
    def GetBlockByHeight(self,
        request: global___GetBlockByHeightRequest,
        context: grpc.ServicerContext,
    ) -> global___GetBlockByHeightResponse: ...

    @abc.abstractmethod
    def GetLatestValidatorSet(self,
        request: global___GetLatestValidatorSetRequest,
        context: grpc.ServicerContext,
    ) -> global___GetLatestValidatorSetResponse: ...

    @abc.abstractmethod
    def GetValidatorSetByHeight(self,
        request: global___GetValidatorSetByHeightRequest,
        context: grpc.ServicerContext,
    ) -> global___GetValidatorSetByHeightResponse: ...


def add_ServiceServicer_to_server(servicer: ServiceServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Counts:grpc.UnaryUnaryMultiCallable[
        global___QueryCountsRequest,
        global___QueryCountsResponse] = ...

    Data:grpc.UnaryUnaryMultiCallable[
        global___QueryDataRequest,
        global___QueryDataResponse] = ...

    DataSource:grpc.UnaryUnaryMultiCallable[
        global___QueryDataSourceRequest,
        global___QueryDataSourceResponse] = ...

    OracleScript:grpc.UnaryUnaryMultiCallable[
        global___QueryOracleScriptRequest,
        global___QueryOracleScriptResponse] = ...

    Request:grpc.UnaryUnaryMultiCallable[
        global___QueryRequestRequest,
        global___QueryRequestResponse] = ...

    PendingRequests:grpc.UnaryUnaryMultiCallable[
        global___QueryPendingRequestsRequest,
        global___QueryPendingRequestsResponse] = ...

    Validator:grpc.UnaryUnaryMultiCallable[
        global___QueryValidatorRequest,
        global___QueryValidatorResponse] = ...

    Reporters:grpc.UnaryUnaryMultiCallable[
        global___QueryReportersRequest,
        global___QueryReportersResponse] = ...

    ActiveValidators:grpc.UnaryUnaryMultiCallable[
        global___QueryActiveValidatorsRequest,
        global___QueryActiveValidatorsResponse] = ...

    Params:grpc.UnaryUnaryMultiCallable[
        global___QueryParamsRequest,
        global___QueryParamsResponse] = ...

    RequestSearch:grpc.UnaryUnaryMultiCallable[
        global___QueryRequestSearchRequest,
        global___QueryRequestSearchResponse] = ...

    RequestPrice:grpc.UnaryUnaryMultiCallable[
        global___QueryRequestPriceRequest,
        global___QueryRequestPriceResponse] = ...

    RequestVerification:grpc.UnaryUnaryMultiCallable[
        global___QueryRequestVerificationRequest,
        global___QueryRequestVerificationResponse] = ...

    RequestPool:grpc.UnaryUnaryMultiCallable[
        global___QueryRequestPoolRequest,
        global___QueryRequestPoolResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Counts(self,
        request: global___QueryCountsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryCountsResponse: ...

    @abc.abstractmethod
    def Data(self,
        request: global___QueryDataRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDataResponse: ...

    @abc.abstractmethod
    def DataSource(self,
        request: global___QueryDataSourceRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDataSourceResponse: ...

    @abc.abstractmethod
    def OracleScript(self,
        request: global___QueryOracleScriptRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryOracleScriptResponse: ...

    @abc.abstractmethod
    def Request(self,
        request: global___QueryRequestRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryRequestResponse: ...

    @abc.abstractmethod
    def PendingRequests(self,
        request: global___QueryPendingRequestsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryPendingRequestsResponse: ...

    @abc.abstractmethod
    def Validator(self,
        request: global___QueryValidatorRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryValidatorResponse: ...

    @abc.abstractmethod
    def Reporters(self,
        request: global___QueryReportersRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryReportersResponse: ...

    @abc.abstractmethod
    def ActiveValidators(self,
        request: global___QueryActiveValidatorsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryActiveValidatorsResponse: ...

    @abc.abstractmethod
    def Params(self,
        request: global___QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryParamsResponse: ...

    @abc.abstractmethod
    def RequestSearch(self,
        request: global___QueryRequestSearchRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryRequestSearchResponse: ...

    @abc.abstractmethod
    def RequestPrice(self,
        request: global___QueryRequestPriceRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryRequestPriceResponse: ...

    @abc.abstractmethod
    def RequestVerification(self,
        request: global___QueryRequestVerificationRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryRequestVerificationResponse: ...

    @abc.abstractmethod
    def RequestPool(self,
        request: global___QueryRequestPoolRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryRequestPoolResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...
